django-wsgi -- WSGI as first-class citizen in Django
====================================================

.. image:: https://travis-ci.org/2degrees/django-wsgi.svg?branch=master
    :target: https://travis-ci.org/2degrees/django-wsgi

.. image:: https://coveralls.io/repos/2degrees/django-wsgi/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/2degrees/django-wsgi?branch=master

django-wsgi unlocks Django applications so developers can take advantage of the
wealth of existing WSGI software, as the other popular Python frameworks do. It
won't break you existing Django applications because it's 100% compatible with
Django and you can start using the functionality offered by this library
progressively. It should be really easy to get started, particularly for
developers who are familiar with frameworks like Pylons or TurboGears.
